package cmd

import (
	"encoding/json"
	"fmt"
	"gitea.stuzer.link/stuzer05/docker-registry-manager/internal/app"
	"net/http"
)

func RegistryTags(app *app.App, imageName string) {
	type tagList struct {
		Tags []string `json:"tags"`
	}

	resp, err := http.Get(fmt.Sprintf("%s/v2/%s/tags/list", app.RegistryURL, imageName))
	if err != nil {
		fmt.Println("Error fetching tags:", err)
		return
	}
	defer resp.Body.Close()

	if resp.StatusCode == http.StatusNotFound {
		fmt.Printf("Error: Image '%s' not found in the registry.\n", imageName)
		return
	}

	var tl tagList
	if err := json.NewDecoder(resp.Body).Decode(&tl); err != nil {
		fmt.Println("Error decoding response:", err)
		return
	}

	if len(tl.Tags) == 0 {
		fmt.Printf("No tags found for image: %s\n", imageName)
	} else {
		for _, tag := range tl.Tags {
			fmt.Println(tag)
		}
	}
}
